pub struct Page {
pub title: String,
pub badge: Option<u8>,
pub score: Option<(u8, i16)>,
pub theme: Option<u32>,
pub content: Vec<Block>,
}Fields
title: StringThe page name as appears in the Table of Contents.
badge: Option<u8>Show the page only when the given badge is unlocked.
score: Option<(u8, i16)>Show the page only when the given score is reached on the given board.
theme: Option<u32>Encoded color scheme.
It’s encoded the same way as in Settings.
content: Vec<Block>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Page
impl<'de> Deserialize<'de> for Page
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more