Request

Enum Request 

pub enum Request<'a> {
Show 17 variants NetStart, NetStop, NetLocalAddr, NetAdvertise, NetRecv, NetSend([u8; 6], &'a [u8]), NetSendStatus([u8; 6]), ReadInput, WifiScan, WifiConnect(&'a str, &'a str), WifiStatus, WifiDisconnect, TcpConnect(u32, u16), TcpStatus, TcpSend(&'a [u8]), TcpRecv, TcpClose,
}
Request that the main chip sends to the IO chip.

Variants



NetStart

Start listening for messages.



NetStop

Stop accepting new messages and connections.



NetLocalAddr

Get MAC address of this device’s IO chip.



NetAdvertise

Broadcast advertisement message.



NetRecv

Read an incoming message (if any) from the IO chip.



NetSend([u8; 6], &'a [u8])

Send an outgoing message to the IO chip.



NetSendStatus([u8; 6])

Get send status of the previous message for the peer.



ReadInput

Get the latest touchpad and buttons inputs.



WifiScan

Scan the air for available non-hidden wifi access points.



WifiConnect(&'a str, &'a str)

Connect to an access point using the given SSID and password.

Async. Check Request::WifiStatus to see if the device is actually connected.



WifiStatus

Get the current connection status to an AP.

Since Request::WifiConnect is async, make sure to account for races. For instance, shortly after requesting a connect, the status might still indicate the status of the previous connection.



WifiDisconnect

Disconnect from the currently connected wifi access point.



TcpConnect(u32, u16)

Connect to the TCP server with the given IP address and port number.

There can be only one open TCP connection at a time.



TcpStatus

Fetch the state of the currently open TCP connection.



TcpSend(&'a [u8])

Send the given bytes into the currently open TCP connection.



TcpRecv

Read a bytes chunk from the currently open TCP connection.



TcpClose

Close the currently open TCP connection.