pub struct DeviceInfo {
pub model: u8,
pub serial: u32,
pub main_version: (u8, u8, u8),
pub io_version: (u8, u8, u8),
pub main_partition: u8,
pub io_partition: u8,
}Expand description
Hardware and firmware info stored in sys/device.
Unlike Settings, device info cannot be directly changed by the user.
Some of these, however, can be changed with firmware updates.
Fields
model: u8Hardware version.
serial: u32Device serial number.
main_version: (u8, u8, u8)Main chip firmware version.
io_version: (u8, u8, u8)IO chip firmware version.
main_partition: u8Currently active partition on the main chip.
io_partition: u8Currently active partition on the IO chip.